aboutsummaryrefslogtreecommitdiffstats
path: root/dashboard
diff options
context:
space:
mode:
authorDmitry Vyukov <dvyukov@google.com>2019-08-31 19:06:56 -0700
committerDmitry Vyukov <dvyukov@google.com>2019-09-01 20:42:31 -0700
commit584f940bafc44c485df4bdddca341ab7893f48ef (patch)
tree4c65338ff1e007cdb67ced8fdf26d2985b9da118 /dashboard
parent9a1a17ad11f7ac82fad35cae38114c67edec1880 (diff)
dashboard/app: fix fix bisection tests
Currently TestBisectFixRetry fails because it assumes emails about crash on ToT are not sent. But we currently send them in tests. Make the behavior consistent between tests and prod. Update #1371
Diffstat (limited to 'dashboard')
-rw-r--r--dashboard/app/jobs.go10
1 files changed, 6 insertions, 4 deletions
diff --git a/dashboard/app/jobs.go b/dashboard/app/jobs.go
index 23595e72d..9fadcb68d 100644
--- a/dashboard/app/jobs.go
+++ b/dashboard/app/jobs.go
@@ -575,10 +575,12 @@ func pollCompletedJobs(c context.Context, typ string) ([]*dashapi.BugReport, err
continue
}
// TODO: this is temporal for gradual bisection rollout.
- // Notify only about successful bisection for now.
- // Note: If BisectFix results in a crash on HEAD, no notification is sent out. The following
- // check also accounts for that condition.
- if !appengine.IsDevAppServer() && job.Type != JobTestPatch && len(job.Commits) != 1 {
+ // Notify only about successful cause bisection for now.
+ if !appengine.IsDevAppServer() && job.Type == JobBisectCause && len(job.Commits) != 1 {
+ continue
+ }
+ // If BisectFix results in a crash on HEAD, no notification is sent out.
+ if job.Type == JobBisectFix && len(job.Commits) != 1 {
continue
}
rep, err := createBugReportForJob(c, job, keys[i], reporting.Config)